/*
 * Generated by util/mkerr.pl DO NOT EDIT
 * Copyright 1995-2026 The OpenSSL Project Authors. All Rights Reserved.
 *
 * Licensed under the Apache License 2.0 (the "License").  You may not use
 * this file except in compliance with the License.  You can obtain a copy
 * in the file LICENSE in the source distribution or at
 * https://www.openssl.org/source/license.html
 */

#ifndef OPENSSL_X509ERR_H
#define OPENSSL_X509ERR_H
#pragma once

#include <openssl/opensslconf.h>
#include <openssl/symhacks.h>
#include <openssl/cryptoerr_legacy.h>

/*
 * X509 reason codes.
 */
#define X509_R_AKID_MISMATCH 110
#define X509_R_BAD_SELECTOR 133
#define X509_R_BAD_X509_FILETYPE 100
#define X509_R_BASE64_DECODE_ERROR 118
#define X509_R_CANT_CHECK_DH_KEY 114
#define X509_R_CERTIFICATE_VERIFICATION_FAILED 139
#define X509_R_CERT_ALREADY_IN_HASH_TABLE 101
#define X509_R_CRL_ALREADY_DELTA 127
#define X509_R_CRL_SIGNATURE_ALGORITHM_MISMATCH 147
#define X509_R_CRL_VERIFY_FAILURE 131
#define X509_R_DUPLICATE_ATTRIBUTE 140
#define X509_R_ERROR_GETTING_MD_BY_NID 141
#define X509_R_ERROR_USING_SIGINF_SET 142
#define X509_R_IDP_MISMATCH 128
#define X509_R_INVALID_ATTRIBUTES 138
#define X509_R_INVALID_DIRECTORY 113
#define X509_R_INVALID_DISTPOINT 143
#define X509_R_INVALID_FIELD_NAME 119
#define X509_R_INVALID_TRUST 123
#define X509_R_ISSUER_MISMATCH 129
#define X509_R_KEY_TYPE_MISMATCH 115
#define X509_R_KEY_VALUES_MISMATCH 116
#define X509_R_LOADING_CERT_DIR 103
#define X509_R_LOADING_DEFAULTS 104
#define X509_R_METHOD_NOT_SUPPORTED 124
#define X509_R_NAME_TOO_LONG 134
#define X509_R_NEWER_CRL_NOT_NEWER 132
#define X509_R_NO_CERTIFICATE_FOUND 135
#define X509_R_NO_CERTIFICATE_OR_CRL_FOUND 136
#define X509_R_NO_CERT_SET_FOR_US_TO_VERIFY 105
#define X509_R_NO_CRL_FOUND 137
#define X509_R_NO_CRL_NUMBER 130
#define X509_R_PUBLIC_KEY_DECODE_ERROR 125
#define X509_R_PUBLIC_KEY_ENCODE_ERROR 126
#define X509_R_SHOULD_RETRY 106
#define X509_R_UNABLE_TO_FIND_PARAMETERS_IN_CHAIN 107
#define X509_R_UNABLE_TO_GET_CERTS_PUBLIC_KEY 108
#define X509_R_UNKNOWN_KEY_TYPE 117
#define X509_R_UNKNOWN_NID 109
#define X509_R_UNKNOWN_PURPOSE_ID 121
#define X509_R_UNKNOWN_SIGID_ALGS 144
#define X509_R_UNKNOWN_TRUST_ID 120
#define X509_R_UNSUPPORTED_ALGORITHM 111
#define X509_R_UNSUPPORTED_VERSION 145
#define X509_R_WRONG_LOOKUP_TYPE 112
#define X509_R_WRONG_TYPE 122

#endif
